@@ -37,14 +37,15 @@ typedef struct GOST34112012Context
     unsigned int digest_size;
 } GOST34112012Context;
 
-void GOST34112012Init(GOST34112012Context *CTX,
-        const unsigned int digest_size);
+extern void GOST34112012Init(GOST34112012Context *CTX,
+               const unsigned int digest_size);
 
-void GOST34112012Update(GOST34112012Context *CTX, const unsigned char *data,
-        size_t len);
+extern void GOST34112012Update(GOST34112012Context *CTX,
+               const unsigned char *data, size_t len);
 
-void GOST34112012Final(GOST34112012Context *CTX, unsigned char *digest);
+extern void GOST34112012Final(GOST34112012Context *CTX,
+               unsigned char *digest);
 
-void GOST34112012Cleanup(GOST34112012Context *CTX);
+extern void GOST34112012Cleanup(GOST34112012Context *CTX);
 
 #endif /* alg-gost3411-2012-core.h */
